import argparse
import json
import sys


__version__ = '0.0.0.1'


def run(in_io, out_io, cmd):
    for line in in_io:
        if line.strip() == '':
            continue
        js = json.loads(line)
        out = eval(cmd, {'j': js})
        json.dump(out, out_io)
        out_io.write('\n')


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument('cmd')
    args = parser.parse_args()

    run(sys.stdin, sys.stdout, args.cmd)



#!/usr/bin/env python

import os
from setuptools import setup

from jqp import __version__


def read(name):
    return open(os.path.join(os.path.dirname(__file__), name)).read()


setup(
    name='jqp',
    version=__version__,
    description='JSON processor with Python one-liner',
    long_description=read('README.rst'),
    author='Yuya Unno',
    author_email='unnonouno@gmail.com',
    url='https://github.com/unnonouno/jqp',
    license='MIT License',
    packages=['jqp'],
    scripts=['scripts/jqp'],
    test_suite='tests',
    classifiers=[
        'Operating System :: OS Independent',
        'Environment :: Console',
        'Programming Language :: Python',
        'License :: OSI Approved :: MIT License',
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Information Technology',
        'Topic :: Utilities',
    ],
)



try:
    from cStringIO import StringIO
except ImportError:
    from io import StringIO
import unittest

import jqp


class RunTest(unittest.TestCase):

    def test1(self):
        inputs = StringIO('''{"name": "Taro", "age": 10}
''')
        outputs = StringIO()
        jqp.run(inputs, outputs, 'j["name"]')
        self.assertEqual(outputs.getvalue(), '"Taro"\n')
